%define modname fedmsg

Name:           fedmsg
Version:        0.18.2
Release:        %mkrel 1
Summary:        Tools for Fedora Infrastructure real-time messaging
Group:          Networking/Other
License:        LGPLv2+
URL:            http://github.com/ralphbean/fedmsg
Source0:        https://pypi.io/packages/source/f/%{modname}/%{modname}-%{version}.tar.gz

BuildArch:      noarch

Obsoletes:      fedmsg-tweet

BuildRequires:  python-devel
BuildRequires:  python-setuptools

# For tests
BuildRequires:  python-nose
BuildRequires:  python-six
BuildRequires:  python-mock
# Only for the test-replay test which is patched out
#BuidlRequires:  python-sqlalchemy

BuildRequires:  python-moksha-hub >= 1.0.9
BuildRequires:  python-bunch
BuildRequires:  python-daemon
BuildRequires:  python-requests
BuildRequires:  python-m2crypto
BuildRequires:  python-m2ext
BuildRequires:  python-pygments
BuildRequires:  python-fabulous
#BuildRequires:  python-fedora
BuildRequires:  python-psutil
BuildRequires:  python-arrow

Requires:       python-moksha-hub >= 1.0.9
Requires:       python-simplejson
Requires:       python-pyzmq
Requires:       python-daemon
Requires:       python-requests
Requires:       python-m2crypto
Requires:       python-m2ext
Requires:       python-pygments
Requires:       python-fabulous
#Requires:       python-fedora
Requires:       python-psutil
Requires(post): rpm-helper


%description
Python API used around Fedora Infrastructure to send and receive messages with
zeromq.  Includes some CLI tools.

%package announce
Summary: The fedmsg-announce command
Group: Networking/Other
Requires: %{name} = %{version}-%{release}

%description announce
This package contains the fedmsg-announce command for sending announcements.

%package collectd
Summary: A fedmsg plugin for collectd
Group: Networking/Other
Requires: %{name} = %{version}-%{release}

%description collectd
This package contains the fedmsg-collectd command which produces output
suitable for consumption by a collectd plugin.

%package hub
Summary: The FedMsg Hub
Group: Networking/Other
Requires: %{name} = %{version}-%{release}

%description hub
This package contains configuration and init scripts for the FedMsg hub.

%package relay
Summary: The FedMsg Relay
Group: Networking/Other
Requires: %{name} = %{version}-%{release}

%description relay
This package contains configuration and init scripts for the FedMsg relay.

%package irc
Summary: The FedMsg IRC Bot
Group: Networking/Other
Requires: %{name} = %{version}-%{release}

%description irc
This package contains configuration and init scripts for the FedMsg IRC bot.

%package gateway
Summary: The FedMsg Gateway daemon
Group: Networking/Other
Requires: %{name} = %{version}-%{release}

%description gateway
This package contains configuration and init scripts for the FedMsg Gateway.
It will rebroadcast messages from the bus to a specially designated ZMQ pub
socket.  Useful for repeating messages outside a firewall.

%prep
%setup -q -n %{modname}-%{version}

# This only got shipped with fedmsg-0.6.3
rm -f fedmsg.d/_tweet-real.py

# These are failing in mock for fedora.  Investigate why.
# We probably just need a new BuildReq
rm -f fedmsg/tests/test_replay.py
rm -f fedmsg/tests/test_crypto_gpg.py
# Also, sqlalchemy is required for those tests we're knocking out,
# so knock it out too.
sed -i "/'sqlalchemy.*$/d" setup.py

# Temporarily disable signature validation while the timestamp precision bug is
# worked out upstream. -- https://github.com/fedora-infra/fedmsg/pull/186
sed -i "s/validate_signatures=True/validate_signatures=False/g" fedmsg.d/ssl.py

# Copy the development config into the tests dir for the check section
cp -rf fedmsg.d fedmsg/tests/.

%build
%{__python} setup.py build

# Create this temporary symlink that's only needed for the test suite.
ln -s fedmsg/tests/test_certs dev_certs

# Unfortunately, neither of these tests will run on koji since they require
# some network connectivity.  With a note of sadness, we destroy them.
rm fedmsg/tests/test_hub.py
rm fedmsg/tests/test_threads.py
rm fedmsg/tests/test_commands.py


%check
PYTHONPATH=$(pwd) python setup.py test

%install
%{__python} setup.py install -O1 --skip-build \
    --install-data=%{_datadir} --root %{buildroot}

%{__mkdir_p} %{buildroot}%{_sysconfdir}/fedmsg.d/
%{__cp} fedmsg.d/*.py %{buildroot}%{_sysconfdir}/fedmsg.d/.

%{__mkdir_p} %{buildroot}/%{_var}/log/%{modname}
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d
cat >  %{buildroot}%{_tmpfilesdir}/%{modname}.conf << EOF
d %{_var}/run/%{modname} 0755 %{modname} %{modname} -
EOF

%{__mkdir_p} %{buildroot}%{_unitdir}
%{__install} initsys/systemd/fedmsg-hub.service \
    %{buildroot}%{_unitdir}/fedmsg-hub.service
%{__install} initsys/systemd/fedmsg-relay.service \
    %{buildroot}%{_unitdir}/fedmsg-relay.service
%{__install} initsys/systemd/fedmsg-irc.service \
    %{buildroot}%{_unitdir}/fedmsg-irc.service
%{__install} initsys/systemd/fedmsg-gateway.service \
    %{buildroot}%{_unitdir}/fedmsg-gateway.service

# Logrotate configuration
%{__mkdir_p} %{buildroot}/%{_sysconfdir}/logrotate.d
%{__install} logrotate %{buildroot}/%{_sysconfdir}/logrotate.d/%{modname}


%pre
%{_sbindir}/groupadd -r %{modname} &>/dev/null || :
%{_sbindir}/useradd  -r -s /sbin/nologin -d %{_datadir}/%{modname} -M \
                     -c 'FedMsg' -g %{modname} %{modname} &>/dev/null || :

%post 
%_tmpfilescreate %{modname}

%files
%doc doc/ README.rst LICENSE
%{_bindir}/fedmsg-logger
%{_bindir}/fedmsg-tail
%{_bindir}/fedmsg-trigger
%{_bindir}/fedmsg-config
%{_bindir}/fedmsg-collectd
%{_bindir}/fedmsg-dg-replay

%attr(755, %{modname}, %{modname}) %dir %{_var}/log/%{modname}
%{_tmpfilesdir}/%{modname}.conf
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}-py%{pyver}.egg-info/

%dir %{_sysconfdir}/fedmsg.d/
%config(noreplace) %{_sysconfdir}/fedmsg.d/base.py*
%config(noreplace) %{_sysconfdir}/fedmsg.d/endpoints.py*
%config(noreplace) %{_sysconfdir}/fedmsg.d/logging.py*
%config(noreplace) %{_sysconfdir}/fedmsg.d/ssl.py*

%config(noreplace) %{_sysconfdir}/logrotate.d/%{modname}

%files announce
%{_bindir}/fedmsg-announce

%files collectd
%{_bindir}/fedmsg-collectd

%files hub
%{_bindir}/fedmsg-hub
%{_unitdir}/fedmsg-hub.service

%files relay
%{_bindir}/fedmsg-relay
%{_unitdir}/fedmsg-relay.service

%config(noreplace) %{_sysconfdir}/fedmsg.d/relay.py*

%files irc
%{_bindir}/fedmsg-irc
%{_unitdir}/fedmsg-irc.service

%config(noreplace) %{_sysconfdir}/fedmsg.d/ircbot.py*

%files gateway
%{_bindir}/fedmsg-gateway
%{_unitdir}/fedmsg-gateway.service
%config(noreplace) %{_sysconfdir}/fedmsg.d/gateway.py*



%changelog
* Thu Jan 26 2017 philippem <philippem> 0.18.2-1.mga6
+ Revision: 1083477
- update to 0.18.2, fix CVE-2017-1000001 mga#20176

* Fri Apr 29 2016 philippem <philippem> 0.17.2-1.mga6
+ Revision: 1007938
- update to 0.17.2

* Tue Feb 02 2016 umeabot <umeabot> 0.10.0-5.mga6
+ Revision: 931952
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.10.0-4.mga5
+ Revision: 748082
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.10.0-3.mga5
+ Revision: 726236
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.10.0-2.mga5
+ Revision: 679117
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 philippem <philippem> 0.10.0-1.mga5
+ Revision: 669729
- update to 0.10.0

* Mon Aug 11 2014 philippem <philippem> 0.9.3-1.mga5
+ Revision: 661713
- add new command fedmsg-dg-replay
- update to 0.9.3

* Sat May 31 2014 pterjan <pterjan> 0.8.0-2.mga5
+ Revision: 628175
- Rebuild for new Python

* Wed May 14 2014 philippem <philippem> 0.8.0-1.mga5
+ Revision: 622820
- update to 0.8.0

* Sun Mar 30 2014 philippem <philippem> 0.7.7-1.mga5
+ Revision: 610403
- update to 0.7.7

* Sun Mar 02 2014 philippem <philippem> 0.7.6-1.mga5
+ Revision: 598609
- update to 2.7.6

* Sat Mar 01 2014 philippem <philippem> 0.7.5-2.mga5
+ Revision: 598264
- fix require on python-pyzmq

* Tue Feb 25 2014 philippem <philippem> 0.7.5-1.mga5
+ Revision: 597195
- use _tmpfilescreate
- imported package fedmsg

